@@ -5,11 +5,11 @@
  * @date     Tue Aug 05, 2003 21:50
  * @brief    XMMS GNOME applet callbacks
  *
- * $Id: callbacks.c,v 1.7 2004/09/05 10:20:03 aleix Exp $
+ * $Id: callbacks.c,v 1.12 2005/01/05 00:22:54 aleix Exp $
  *
  * @if copyright
  *
- * Copyright (C) 2003, 2004 Aleix Conchillo Flaque
+ * Copyright (C) 2003, 2004, 2005 Aleix Conchillo Flaque
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,9 +35,7 @@
 #include "callbacks.h"
 
 #include "interface.h"
-#include "xmmsctrl.h"
-
-#include <xmms/xmmsctrl.h>
+#include "playerctrl.h"
 
 #include <gnome.h>
 
@@ -102,31 +100,31 @@ cb_change_orient(GtkWidget *w, PanelAppletOrient orient, XMMSData *xmms)
 void
 cb_prev_clicked(GtkWidget *w, XMMSData *xmms)
 {
-    xmms_prev(xmms);
+    player_prev(xmms);
 }
 
 void
 cb_play_pause_clicked(GtkWidget *w, XMMSData *xmms)
 {
-    xmms_play_pause(xmms);
+    player_play_pause(xmms);
 }
 
 void
 cb_stop_clicked(GtkWidget *w, XMMSData *xmms)
 {
-    xmms_stop(xmms);
+    player_stop(xmms);
 }
 
 void
 cb_next_clicked(GtkWidget *w, XMMSData *xmms)
 {
-    xmms_next(xmms);
+    player_next(xmms);
 }
 
 void
 cb_eject_clicked(GtkWidget *w, XMMSData *xmms)
 {
-    xmms_eject(xmms);
+    player_eject(xmms);
 }
 
 gboolean
@@ -158,7 +156,7 @@ cb_seek(GtkWidget *w, GdkEventButton *event, gpointer data)
     {
         t = event->y / (gdouble) (requisition.height - 1);
     }
-    xmms_seek(xmms, t);
+    player_seek(xmms, t);
 
     return FALSE;
 }
@@ -169,11 +167,11 @@ cb_scrollwheel(GtkWidget *w, GdkEventScroll *event, XMMSData *xmms)
     switch (event->direction)
     {
     case GDK_SCROLL_UP:
-        xmms_raise_volume(xmms);
+        player_raise_volume(xmms);
         return TRUE;
         break;
     case GDK_SCROLL_DOWN:
-        xmms_lower_volume(xmms);
+        player_lower_volume(xmms);
         return TRUE;
         break;
     default:
@@ -211,7 +209,7 @@ cb_toggle_repeat(BonoboUIComponent *uic, const gchar *path,
                  Bonobo_UIComponent_EventType type, const gchar *state,
                  XMMSData *xmms)
 {
-    xmms_repeat(xmms, strcmp(state, "0"));
+    player_repeat(xmms, strcmp(state, "0"));
 }
 
 void
@@ -219,38 +217,44 @@ cb_toggle_shuffle(BonoboUIComponent *uic, const gchar *path,
                   Bonobo_UIComponent_EventType type, const gchar *state,
                   XMMSData *xmms)
 {
-    xmms_shuffle(xmms, strcmp(state, "0"));
+    player_shuffle(xmms, strcmp(state, "0"));
 }
 
 
 void
 cb_main_win_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb)
 {
-    xmms_main_win(xmms);
+    player_main_win(xmms, !player_is_main_win(xmms));
 }
 
 void
 cb_pl_win_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb)
 {
-    xmms_pl_win(xmms);
+    player_pl_win(xmms, !player_is_pl_win(xmms));
 }
 
 void
 cb_eq_win_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb)
 {
-    xmms_eq_win(xmms);
+    player_eq_win(xmms, !player_is_eq_win(xmms));
 }
 
 void
 cb_show_hide_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb)
 {
-    xmms_show_hide(xmms);
+    player_show_hide(xmms);
 }
 
 void
-cb_xmms_pref_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb)
+cb_player_pref_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb)
 {
-    xmms_preferences(xmms);
+    player_preferences(xmms);
+}
+
+void
+cb_quit_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb)
+{
+    player_quit(xmms);
 }
 
 void
@@ -269,10 +273,14 @@ cb_about_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb)
         return;
     }
     about = gnome_about_new(
-        PACKAGE_NAME, PACKAGE_VERSION, "Copyright (C) 2003, 2004 Aleix Conchillo Flaque\n",
-        _("gxmms lets you control the X MultiMedia System (XMMS).\n"),
+        PACKAGE_NAME, PACKAGE_VERSION, "Copyright (C) 2003, 2004, 2005 Aleix Conchillo Flaque\n",
+        _("gxmms lets you control XMMS or Beep Media Player.\n"),
         authors, NULL, NULL,
-        gdk_pixbuf_new_from_file(GXMMS_DATADIR"/gxmsms.png", 0));
+#ifdef HAVE_XMMS
+        gdk_pixbuf_new_from_file(GXMMS_DATADIR"/gxmms.png", 0));
+#else
+        gdk_pixbuf_new_from_file(GXMMS_BMP_DATADIR"/gxmms_bmp.png", 0));
+#endif
 
     g_signal_connect(G_OBJECT(about), "destroy",
                      G_CALLBACK(gtk_widget_destroyed), &about);
@@ -289,13 +297,12 @@ timer(gpointer data)
 
     // if xmms has been closed or if it was playing
     if (was_playing
-        && (!xmms_remote_is_playing(xmms->session)
-            || !xmms_remote_is_running(xmms->session)))
+        && (!player_is_playing(xmms) || !player_is_running(xmms)))
     {
         gui_update(xmms);
         was_playing = FALSE;
     }
-    if (xmms_remote_is_playing(xmms->session))
+    if (player_is_playing(xmms))
     {
         gui_update(xmms);
         was_playing = TRUE;
