@@ -5,7 +5,7 @@
  * @date     Tue Aug 05, 2003 21:56
  * @brief    XMMS GNOME applet callbacks
  *
- * $Id: callbacks.h,v 1.4 2004/09/05 10:18:15 aleix Exp $
+ * $Id: callbacks.h,v 1.6 2004/12/30 00:24:11 aleix Exp $
  *
  * @if copyright
  *
@@ -87,8 +87,10 @@ void cb_eq_win_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb);
 void cb_show_hide_menu(BonoboUIComponent *uic, XMMSData *xmms,
                        const gchar *verb);
 
-void cb_xmms_pref_menu(BonoboUIComponent *uic, XMMSData *xmms,
-                       const gchar *verb);
+void cb_player_pref_menu(BonoboUIComponent *uic, XMMSData *xmms,
+                         const gchar *verb);
+
+void cb_quit_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb);
 
 void cb_about_menu(BonoboUIComponent *uic, XMMSData *xmms, const gchar *verb);
 
