@@ -5,11 +5,11 @@
  * @date     Tue Aug 05, 2003 21:59
  * @brief    XMMS GNOME applet GUI
  *
- * $Id: interface.c,v 1.5 2004/09/07 15:02:47 aleix Exp $
+ * $Id: interface.c,v 1.9 2005/01/05 00:22:54 aleix Exp $
  *
  * @if copyright
  *
- * Copyright (C) 2003, 2004 Aleix Conchillo Flaque
+ * Copyright (C) 2003, 2004, 2005 Aleix Conchillo Flaque
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,8 +31,11 @@
 #include "interface.h"
 
 #include "callbacks.h"
+#include "playerctrl.h"
 
-#include <xmms/xmmsctrl.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <string.h>
 
@@ -227,7 +230,7 @@ gui_update(XMMSData *xmms)
     gchar info[256] = _("No track");
 
     progress = xmms->track_control.progress;
-    if (!xmms_remote_is_running(xmms->session))
+    if (!player_is_running(xmms))
     {
         gtk_tooltips_set_tip(xmms->tooltips, xmms->track_control.box, info,
                              NULL);
@@ -235,10 +238,10 @@ gui_update(XMMSData *xmms)
         return;
     }
 
-    pos = xmms_remote_get_playlist_pos(xmms->session);
-    track = xmms_remote_get_playlist_title(xmms->session, pos);
-    total_time = xmms_remote_get_playlist_time(xmms->session, pos);
-    cur_time = xmms_remote_get_output_time(xmms->session);
+    pos = player_get_playlist_pos(xmms);
+    track = player_get_playlist_title(xmms, pos);
+    total_time = player_get_playlist_time(xmms, pos);
+    cur_time = player_get_output_time(xmms);
 
     width = total_time ? ((gdouble) cur_time / (gdouble) total_time) : 0;
 
@@ -257,11 +260,9 @@ gui_update(XMMSData *xmms)
     popup = panel_applet_get_popup_component(PANEL_APPLET(xmms->applet));
 
     bonobo_ui_component_set_prop(popup, "/commands/Repeat", "state",
-                                 xmms_remote_is_repeat(xmms->session) ? "1" : "0",
-                                 NULL);
+                                 player_is_repeat(xmms) ? "1" : "0", NULL);
     bonobo_ui_component_set_prop(popup, "/commands/Shuffle", "state",
-                                 xmms_remote_is_shuffle(xmms->session) ? "1" : "0",
-                                 NULL);
+                                 player_is_shuffle(xmms) ? "1" : "0", NULL);
 }
 
 void
@@ -299,6 +300,11 @@ gui_show_error(XMMSData *xmms, const gchar *msg)
 static void
 init_menu(XMMSData *xmms)
 {
+#ifdef HAVE_XMMS
+    static const char* menu_xml_file = "GNOME_gxmmsApplet.xml";
+#else
+    static const char* menu_xml_file = "GNOME_gxmms_bmpApplet.xml";
+#endif
     static const BonoboUIVerb gxmms_menu_verbs[] = {
         BONOBO_UI_UNSAFE_VERB("Repeat",   cb_repeat_menu),
         BONOBO_UI_UNSAFE_VERB("Shuffle",  cb_shuffle_menu),
@@ -306,7 +312,8 @@ init_menu(XMMSData *xmms)
         BONOBO_UI_UNSAFE_VERB("PlWin",    cb_pl_win_menu),
         BONOBO_UI_UNSAFE_VERB("EQWin",    cb_eq_win_menu),
         BONOBO_UI_UNSAFE_VERB("ShowHide", cb_show_hide_menu),
-        BONOBO_UI_UNSAFE_VERB("XMMSPref", cb_xmms_pref_menu),
+        BONOBO_UI_UNSAFE_VERB("Prefer",   cb_player_pref_menu),
+        BONOBO_UI_UNSAFE_VERB("Quit",     cb_quit_menu),
         BONOBO_UI_UNSAFE_VERB("About",    cb_about_menu),
         BONOBO_UI_VERB_END
     };
@@ -315,7 +322,7 @@ init_menu(XMMSData *xmms)
 
     panel_applet_setup_menu_from_file(PANEL_APPLET(applet),
                                       NULL,
-                                      "GNOME_gxmmsApplet.xml",
+                                      menu_xml_file,
                                       NULL,
                                       gxmms_menu_verbs,
                                       xmms);
@@ -330,11 +337,9 @@ init_menu(XMMSData *xmms)
                                      xmms);
 
     bonobo_ui_component_set_prop(popup, "/commands/Repeat", "state",
-                                 xmms_remote_is_repeat(xmms->session) ? "1" : "0",
-                                 NULL);
+                                 player_is_repeat(xmms) ? "1" : "0", NULL);
     bonobo_ui_component_set_prop(popup, "/commands/Shuffle", "state",
-                                 xmms_remote_is_shuffle(xmms->session) ? "1" : "0",
-                                 NULL);
+                                 player_is_shuffle(xmms) ? "1" : "0", NULL);
 }
 
 static void
@@ -364,7 +369,11 @@ register_stock_icons(XMMSData *xmms, GtkIconFactory *factory)
 	GtkIconSet *icon_set;
         GError *error = NULL;
 
+#ifdef HAVE_XMMS
         sprintf(file_name, "%s/%s%s", GXMMS_DATADIR, items[i], GXMMS_IMAGE_EXT);
+#else
+        sprintf(file_name, "%s/%s%s", GXMMS_BMP_DATADIR, items[i], GXMMS_IMAGE_EXT);
+#endif
 	pixbuf = gdk_pixbuf_new_from_file(file_name, &error);
         if (pixbuf == NULL)
         {
